@@ -35,14 +35,14 @@ test_that("language is a single string",{
                                simplify = TRUE,
                                language = c("en", "fr"),
                                key = "abc"),
-                "language must be a single character vector or string")
+                "language must be a single string")
 
   expect_error(google_timezone(location = c(-37.81659, 144.9841),
                                timestamp = as.POSIXct("2016-06-05"),
                                simplify = TRUE,
                                language = 1,
                                key = "abc"),
-               "language must be a single character vector or string")
+               "language must be a single string")
 
 })
 
